# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/fastpolvo',
                'doc_host': 'https://lgvaz.github.io',
                'git_url': 'https://github.com/lgvaz/fastpolvo',
                'lib_path': 'fastpolvo'},
  'syms': { 'fastpolvo.classification.baseline.baseline': { 'fastpolvo.classification.baseline.baseline.FastaiMetricWrapper': ( 'classification.baseline.baseline.html#fastaimetricwrapper',
                                                                                                                                'fastpolvo/classification/baseline/baseline.py'),
                                                            'fastpolvo.classification.baseline.baseline.FastaiMetricWrapper.__init__': ( 'classification.baseline.baseline.html#fastaimetricwrapper.__init__',
                                                                                                                                         'fastpolvo/classification/baseline/baseline.py'),
                                                            'fastpolvo.classification.baseline.baseline.FastaiMetricWrapper.accumulate': ( 'classification.baseline.baseline.html#fastaimetricwrapper.accumulate',
                                                                                                                                           'fastpolvo/classification/baseline/baseline.py'),
                                                            'fastpolvo.classification.baseline.baseline.calculate_metrics': ( 'classification.baseline.baseline.html#calculate_metrics',
                                                                                                                              'fastpolvo/classification/baseline/baseline.py'),
                                                            'fastpolvo.classification.baseline.baseline.fixed_probs': ( 'classification.baseline.baseline.html#fixed_probs',
                                                                                                                        'fastpolvo/classification/baseline/baseline.py'),
                                                            'fastpolvo.classification.baseline.baseline.random_probs': ( 'classification.baseline.baseline.html#random_probs',
                                                                                                                         'fastpolvo/classification/baseline/baseline.py')},
            'fastpolvo.classification.explorer': { 'fastpolvo.classification.explorer.DataExplorer': ( 'classification.explorer.html#dataexplorer',
                                                                                                       'fastpolvo/classification/explorer.py'),
                                                   'fastpolvo.classification.explorer.DataExplorer.__init__': ( 'classification.explorer.html#dataexplorer.__init__',
                                                                                                                'fastpolvo/classification/explorer.py'),
                                                   'fastpolvo.classification.explorer.DataExplorer.from_datasets': ( 'classification.explorer.html#dataexplorer.from_datasets',
                                                                                                                     'fastpolvo/classification/explorer.py')},
            'fastpolvo.core': { 'fastpolvo.core.one_batch_with_idxs': ('core.html#one_batch_with_idxs', 'fastpolvo/core.py'),
                                'fastpolvo.core.show_tfms': ('core.html#show_tfms', 'fastpolvo/core.py')},
            'fastpolvo.data.transforms': { 'fastpolvo.data.transforms.AlignOrientation': ( 'data.transforms.html#alignorientation',
                                                                                           'fastpolvo/data/transforms.py'),
                                           'fastpolvo.data.transforms.AlignOrientation.__init__': ( 'data.transforms.html#alignorientation.__init__',
                                                                                                    'fastpolvo/data/transforms.py'),
                                           'fastpolvo.data.transforms.AlignOrientation.encodes': ( 'data.transforms.html#alignorientation.encodes',
                                                                                                   'fastpolvo/data/transforms.py'),
                                           'fastpolvo.data.transforms.FlipVert': ( 'data.transforms.html#flipvert',
                                                                                   'fastpolvo/data/transforms.py'),
                                           'fastpolvo.data.transforms.FlipVert.__init__': ( 'data.transforms.html#flipvert.__init__',
                                                                                            'fastpolvo/data/transforms.py'),
                                           'fastpolvo.data.transforms.FlipVert.encodes': ( 'data.transforms.html#flipvert.encodes',
                                                                                           'fastpolvo/data/transforms.py')},
            'fastpolvo.segmentation.core': { 'fastpolvo.segmentation.core.SegmentationExplorer': ( 'segmentation.core.html#segmentationexplorer',
                                                                                                   'fastpolvo/segmentation/core.py'),
                                             'fastpolvo.segmentation.core.SegmentationExplorer.__init__': ( 'segmentation.core.html#segmentationexplorer.__init__',
                                                                                                            'fastpolvo/segmentation/core.py'),
                                             'fastpolvo.segmentation.core.SegmentationExplorer._group_y': ( 'segmentation.core.html#segmentationexplorer._group_y',
                                                                                                            'fastpolvo/segmentation/core.py'),
                                             'fastpolvo.segmentation.core.SegmentationExplorer.from_datasets': ( 'segmentation.core.html#segmentationexplorer.from_datasets',
                                                                                                                 'fastpolvo/segmentation/core.py'),
                                             'fastpolvo.segmentation.core.SegmentationExplorer.most_common_appearances': ( 'segmentation.core.html#segmentationexplorer.most_common_appearances',
                                                                                                                           'fastpolvo/segmentation/core.py'),
                                             'fastpolvo.segmentation.core.SegmentationExplorer.most_common_pixels': ( 'segmentation.core.html#segmentationexplorer.most_common_pixels',
                                                                                                                      'fastpolvo/segmentation/core.py')}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/05a_classification.explorer.ipynb.

# %% auto 0
__all__ = ['show_tfms', 'DataExplorer']

# %% ../../nbs/05a_classification.explorer.ipynb 4
from fastai.vision.all import *
import polvo as pv
import fastpolvo as fpv

# %% ../../nbs/05a_classification.explorer.ipynb 5
class DataExplorer(pv.classification.DataExplorer):
    def __init__(self, x_tl, y_tl): 
        id2label = y_tl.vocab.__getitem__
        label2id = {l: i for i, l in enumerate(y_tl.vocab)}.__getitem__
        super().__init__(y_tl, x_tl.__getitem__, id2label, label2id)
        
    @classmethod
    def from_datasets(cls, dss):
        return cls(dss.tls[0], dss.tls[1])

# %% ../../nbs/05a_classification.explorer.ipynb 12
show_tfms = fpv.show_tfms



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_core.ipynb.

# %% auto 0
__all__ = ['one_batch_with_idxs', 'show_tfms']

# %% ../nbs/00_core.ipynb 3
from fastai.vision.all import *
import polvo as pv

# %% ../nbs/00_core.ipynb 7
def one_batch_with_idxs(
    dl, # A `DataLoader` instance. Commonly `dls.train` or `dls.valid`
    unique_idx=None, # If specified, show only images with index `unique_idx`.
):
    "Show original and transformed version of images."
    old_get_idxs = dl.get_idxs

    idxs = dl.get_idxs() if unique_idx is None else [unique_idx] * len(dl.items)
    dl.get_idxs = lambda: idxs
    x, y = dl.one_batch()

    dl.get_idxs = old_get_idxs
    
    return (x, y), idxs

# %% ../nbs/00_core.ipynb 8
@delegates(pv.image_grid)
def show_tfms(
    dl, # A `DataLoader` instance. Commonly `dls.train` or `dls.valid`
    unique_idx=None, # If specified, show only images with index `unique_idx`.
    max_n=5, # Maximum number of samples.
    pad=0.2,
    ncols=2,
    **kwargs,
):
    "Show original and transformed version of images."
    (xs, ys), idxs = one_batch_with_idxs(dl, unique_idx=unique_idx)
    
    shows = []
    xmax, ymax = 0, 0 # Has to be passed to show grid so images are not cut when displayed
    for i, x, idx in zip(range(max_n), xs, idxs):
        orig = dl.dataset[idx]
        image = orig[0]
        xmax = max(xmax, x.shape[2], image.shape[1])
        ymax = max(ymax, x.shape[1], image.shape[0])
        
        def _s(ax, orig=orig, idx=idx): return dl.dataset.show(orig, ctx=show_title(idx, ctx=ax))
        shows.append(_s)

    fig, grid = pv.get_image_grid(nrows=len(shows), ncols=ncols, pad=pad, **kwargs)
    
    dl.show_batch((xs, ys), ctxs=grid[1::2], show=True)
    pv.show_grid(grid[::2], shows, show=False)
    pv.normalize_axes(grid, xmax=xmax, ymax=ymax)
    
    return fig, grid



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/03f_data.transforms.ipynb.

# %% auto 0
__all__ = ['FlipVert', 'AlignOrientation']

# %% ../../nbs/03f_data.transforms.ipynb 4
from fastai.vision.all import *
import polvo as pv
import fastpolvo as fpv

# %% ../../nbs/03f_data.transforms.ipynb 5
class FlipVert(RandTransform):
    order = 30
    @delegates(RandTransform.__init__)
    def __init__(self, p=0.5, **kwargs):
        "Batch transform for flipping images vertically"
        super().__init__(p=p, **kwargs)
        
    def encodes(self, x:TensorImage): return torch.flip(x, [2]) # (BS, C, H, W)
    def encodes(self, x:TensorMask): return torch.flip(x, [1]) # only 3 channels (BS, H, W)

# %% ../../nbs/03f_data.transforms.ipynb 8
class AlignOrientation(Transform):
    @delegates(Transform.__init__)
    def __init__(self, orientation='vertical', **kwargs):
        "Keep all images in same orientation"
        self.orientation = orientation
        super().__init__(**kwargs)
        
    def encodes(self, x:Image.Image):
        w, h = x.size
        if w>h and self.orientation=='vertical': x = x.rotate(90, expand=True)
        elif h>w and self.orientation=='horizontal': x = x.rotate(90, expand=True)
        return x
